# v0.1.30 2022-12-28
- Fix: empty URL in Postman collection item

# v0.1.29 2022-12-28
- Fix: flattened nested folders of Postman collection file using DFS

# v0.1.28 2022-12-28
- Health check
- Idempotency check
- Other minor fixes